package cc.smtweb.system.bpm.web.engine.model.listcard.lclc1;

import cc.smtweb.framework.core.cache.AbstractCache;
import cc.smtweb.framework.core.cache.CacheManager;
import cc.smtweb.framework.core.common.R;
import cc.smtweb.framework.core.db.DbEngine;
import cc.smtweb.framework.core.db.EntityDao;
import cc.smtweb.framework.core.db.EntityHelper;
import cc.smtweb.framework.core.db.cache.ModelTableCache;
import cc.smtweb.framework.core.db.jdbc.AbsDbWorker;
import cc.smtweb.framework.core.db.vo.ModelTable;
import cc.smtweb.framework.core.exception.BizException;
import cc.smtweb.system.bpm.web.design.form.define.PageDataset;
import cc.smtweb.system.bpm.web.engine.dynPage.AbstractDynPageHandler;

/**
 * @Author:lip
 * @Date : 2022/9/2 11:44
 */
public class LCLC1DelHandler extends AbstractDynPageHandler {

    /**
     * 左列表删除
     * @return
     */
    public R lLDel(){
        del(LCLC1Handler.dsLList);
        return R.success();
    }

    /**
     * 左卡片删除
     * @return
     */
    public R lCDel(){
        del(LCLC1Handler.dsLCard);
        return R.success();
    }

    /**
     * 右列表删除
     * @return
     */
    public R rLDel(){
        del(LCLC1Handler.dsRList);
        return R.success();
    }

    /**
     * 右卡片删除
     * @return
     */
    public R rCDel(){
        del(LCLC1Handler.dsRCard);
        return R.success();
    }

    private void del(String dsName) {
        long id = params.readLong("id");
        if (id == 0L) throw new BizException("没有收到待删除记录Id(" + id + ")！");
        //数据集
        PageDataset pageDataset = this.datasets.findByName(dsName);

        checkBean(pageDataset, id);

        DbEngine.getInstance().doTrans(new AbsDbWorker() {
            @Override
            public void work() {
                ModelTable table = ModelTableCache.getInstance().get(pageDataset.masterTable);
                if (table == null) throw new BizException("没有找到指定的的表定义：" + pageDataset.name + "！");
                EntityDao dao = DbEngine.getInstance().findDao(table.getName());
                dao.deleteEntity(id);
                localDel(id, table);
            }

            @Override
            public void doAfterDbCommit() {
                ModelTable table = ModelTableCache.getInstance().get(pageDataset.masterTable);
                if (table.isNeedCache()) {
                    AbstractCache cache = CacheManager.getIntance().getCache(table.getName());
                    cache.remove(id);
                }
                localDelSuccess(id, table);
            }
        });
    }

    protected void localDel(long id, ModelTable table) {

    }

    protected void localDelSuccess(long id, ModelTable table) {

    }

    /**
     * 删除校验
     *
     * @param pageDataSet
     * @param id
     */
    protected void checkBean(PageDataset pageDataSet, long id) {
        //校验外键引用关系
        EntityHelper.checkExists(pageDataSet.masterTable, id);
    }
}
