package cc.smtweb.system.bpm.web.engine.model.listcard.lclc1;

import cc.smtweb.framework.core.common.R;
import cc.smtweb.framework.core.common.SwMap;
import cc.smtweb.system.bpm.web.design.form.define.PageDataset;
import cc.smtweb.system.bpm.web.engine.dynPage.AbstractDynPageHandler;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageHelper;
import cc.smtweb.system.bpm.web.engine.dynPage.DynPageListHandler;
import cc.smtweb.system.bpm.web.engine.dynPage.DynRetBean;
import cc.smtweb.system.bpm.web.engine.model.listcard.single.LCSingleHelper;
import org.springframework.util.Assert;

/**
 * @Author:lip
 * @Date : 2022/9/2 11:44
 */
public class LCLC1LoadHandler extends AbstractDynPageHandler {
    /**
     * 左表新增
     * @return
     */
    public R lAdd() {
        SwMap data = add(LCLC1Handler.dsLCard);
        return R.success(LCSingleHelper.buildRetData(LCLC1Handler.dsLCard, data));
    }

    /**
     * 右表新增
     * @return
     */
    public R rAdd() {
        SwMap data = add(LCLC1Handler.dsRCard);
        return R.success(LCSingleHelper.buildRetData(LCLC1Handler.dsRCard, data));
    }

    private SwMap add(String dsName) {
        PageDataset addDataSet = this.datasets.findByName(dsName);
        Assert.notNull(addDataSet, "未获取到数据集:" + dsName);
        SwMap data;
        //懒加载，给个空对象
        if (addDataSet.lazy) {
            data = new SwMap();
        } else {
            data = DynPageHelper.createBean(addDataSet);
        }
        return data;
    }

    /**
     * 左表编辑
     * @return
     */
    public R lLoad() {
        SwMap bean = load(LCLC1Handler.dsLCard);
        return R.success(LCSingleHelper.buildRetData(LCLC1Handler.dsLCard, bean));
    }

    /**
     * 右表编辑
     * @return
     */
    public R rLoad() {
        SwMap bean = load(LCLC1Handler.dsRCard);
        return R.success(LCSingleHelper.buildRetData(LCLC1Handler.dsRCard, bean));
    }

    private SwMap load(String dsName) {
        //过滤条件
        SwMap filter = params.readMap("filter");

        //对应的数据集定义
        PageDataset loadDataSet = this.datasets.findByName(dsName);
        Assert.notNull(loadDataSet, "未获取到数据集:" + dsName);

        return provider.loadData(filter, loadDataSet);
    }

    private DynPageListHandler getListWorker(SwMap filter, PageDataset pageDataSet) {
        DynPageListHandler listHandler = new DynPageListHandler(form.getId(), filter, pageDataSet);
        listHandler.init(params, us);
        return listHandler;
    }

    /**
     * 左列表加载
     * @return
     */
    public R lList(){
        DynRetBean list = list(LCLC1Handler.dsLList);
        return R.success(list);
    }

    /**
     * 右列表加载
     * @return
     */
    public R rList(){
        DynRetBean list = list(LCLC1Handler.dsRList);
        return R.success(list);
    }

    private DynRetBean list(String dsName) {
        //过滤条件
        SwMap filter = params.readMap("filter");

        //对应的数据集定义
        PageDataset listDataSet = this.datasets.findByName(dsName);
        Assert.notNull(listDataSet, "未获取到数据集:" + dsName);

        return DynRetBean.createList(getListWorker(filter, listDataSet).buildListData());
    }

    /**
     * 左列表分页数据
     * @return
     */
    public R getLTotal(){
        return getTotal(LCLC1Handler.dsLList);
    }

    /**
     * 右列表分页数据
     * @return
     */
    public R getRTotal(){
        return getTotal(LCLC1Handler.dsRList);
    }

    private R getTotal(String dsName) {
        //过滤条件
        SwMap filter = params.readMap("filter");

        //对应的数据集定义
        PageDataset listDataSet = this.datasets.findByName(dsName);
        Assert.notNull(listDataSet, "未获取到数据集:" + dsName);

        return getListWorker(filter, listDataSet).getTotal();
    }
}
