package cc.smtweb.system.bpm.web.engine.model.listcard.mastersub;

import cc.smtweb.framework.core.cache.AbstractCache;
import cc.smtweb.framework.core.cache.CacheManager;
import cc.smtweb.framework.core.common.R;
import cc.smtweb.framework.core.common.SwMap;
import cc.smtweb.framework.core.db.DbEngine;
import cc.smtweb.framework.core.db.EntityDao;
import cc.smtweb.framework.core.db.cache.ModelTableCache;
import cc.smtweb.framework.core.db.jdbc.AbsDbWorker;
import cc.smtweb.framework.core.db.vo.ModelTable;
import cc.smtweb.framework.core.exception.BizException;
import cc.smtweb.system.bpm.web.engine.dynPage.AbstractDynPageHandler;
import org.springframework.util.Assert;

/**
 * @Author:lip
 * @Date : 2022/8/28 20:40
 */
public class LCMsDelHandler extends AbstractDynPageHandler {
    /**
     * 删除指定数据集，入参{pageId, dataset, id}
     *
     * @return
     */
    public R del() {
        long id = params.readLong("id");
        if (id <= 0L) throw new BizException("没有收到待删除记录Id(" + id + ")！");
        SwMap props = form.getOpts().readMap("config").readMap("props");
        //主表
        ModelTable masterTable = ModelTableCache.getInstance().get(props.readLong("masterTable",-1L));
        Assert.notNull(masterTable,"未获取到主表配置");

        //获取子表
        ModelTable subTable = ModelTableCache.getInstance().get(props.readLong("subTable",-1L));
        String subForeignKey = props.readString("subForeignKey","-1");
        Assert.isTrue(subTable!= null && !subForeignKey.equals("-1"),"未获取到子表配置");

        //
        DbEngine.getInstance().doTrans(new AbsDbWorker() {
            @Override
            public void work() {
                DbEngine engine = DbEngine.getInstance();
                EntityDao masterDao = engine.findDao(masterTable.getName());
                EntityDao subDao = engine.findDao(subTable.getName());
                masterDao.deleteEntity(id);
                subDao.deleteEntity("where " + subForeignKey + " = ?", id);
            }

            @Override
            public void doAfterDbCommit() {
                if (masterTable.isNeedCache()) {
                    AbstractCache cache = CacheManager.getIntance().getCache(masterTable.getName());
                    cache.remove(id);
                }
                if (subTable.isNeedCache()) {
                    AbstractCache cache = CacheManager.getIntance().getCache(masterTable.getName());
                    cache.remove(id);
                }
            }
        });
        return R.success();
    }
}
